## Spetro

[![PyPI](https://img.shields.io/pypi/v/spetro.svg)](https://pypi.org/project/spetro/)
[![thoughts](https://img.shields.io/badge/docs-thoughts-blue)](docs/thoughts.md)
![Beta](https://img.shields.io/badge/status-beta-orange)
![Beta](https://img.shields.io/badge/beta-orange?style=flat)
![Development Status](https://img.shields.io/badge/dev--status-beta-yellow)
[![api](https://img.shields.io/badge/docs-api-purple)](docs/api.md)
[![Downloads](https://pepy.tech/badge/spetro)](https://pepy.tech/project/spetro)

### installation

```bash
pip install spetro
```

<details>
<summary>Testings</summary>
  
![performance](docs/testings-figure-b.png)

</details>

<details>
<summary>Architecture</summary>
  
![schema](docs/schema-thoughts-figure-a.png)

</details>

